#undef TD_PACKAGE
#undef TD_PACKAGE_DIR
#undef TD_PACKAGE_DATA_DIR
#undef TD_PACKAGE_LOCALE_DIR
#undef TD_PACKAGE_SOURCE_DIR
#undef TD_VERSION
#undef TD_DATEVERSION
#undef PREFIX_WIDGET_CORE
#undef PREFIX_WIDGET_PLUGINS
#undef ENABLE_NLS
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY
#undef HAVE_LIBSM
